
# Pagination constant
DEFAULT_START = 0
DEFAULT_END = 100
DEFAULT_PAGE_SIZE = 10

# Supported earch engine
GOOGLE_ENGINE = 'google'
GOOGLE_SCHOLAR_ENGINE = 'google_scholar'
BAIDU_ENGINE = 'baidu'
BING_ENGINE = 'bing'
YANDEX_ENGINE = 'yandex'
EBAY_ENGINE = 'ebay'
YAHOO_ENGINE = 'yahoo'
HOME_DEPOT_ENGINE = 'home_depot'
YOUTUBE_ENGINE = 'youtube'
DUCKDUCKGO_ENGINE = 'duckduckgo'
WALMART_ENGINE = "walmart"
NAVER_ENGINE = "naver"
APPLE_APP_STORE_ENGINE = "apple_app_store"

# from serpapi.constant import *